@@ -62,6 +62,8 @@ sub new {
 
 	my($self)=$class->SUPER::new(@_);
     $self->_Compile();
+    $self->_DynamicConflicts(); # call it only if dynamic conflict handlers
+
     bless($self,$class);
 }
 ###########
@@ -430,6 +432,40 @@ sub DfaTable {
 
 }
 
+sub _DynamicConflicts {
+  my $self = shift;
+  my $ch = $self->{GRAMMAR}{CONFLICTHANDLERS};
+
+  return unless %$ch;
+
+  my $co = $self->{CONFLICTS}{FORCED}{DETAIL};
+
+  my %C;
+  for my $state (keys %$co) {
+    my @conList = @{$co->{$state}{LIST}};
+
+    for my $c (@conList) {
+      my ($token, $production) = @$c;
+      push @{$C{(0-$production)}{$state}}, $token;
+    }
+  }
+
+  for my $c (keys %$ch) {                 # for each conflict handler
+    my $d = $ch->{$c}{production};        # list of productions managed by this handler
+    for my $p (keys %$d) {               # for each production
+  #    # if $p reduce or shift?
+  #    # find the conflictive states where $p appears
+  #    # if $p is reduce and appears in state $s as -$p it is a state of conflict (the other is in the action table)
+
+       if ($C{$p}) {
+         push @{$ch->{$c}{states}}, $C{$p} 
+       }
+       else {
+         #  check that it is a shift with this production. 
+       }
+    }
+  }
+}
 
 ####################################
 # Method to build Dfa from Grammar #
